/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.util.actions;

import java.awt.event.ActionEvent;
import java.io.Serializable;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.AbstractAction;
import org.netbeans.core.api.multiview.MultiViews;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * <p>Open action for multi views</p>
 * 
 * <p>On action performed will open a MultiView {@link TopComponent} with all the editors for the given mime type</p>
 * 
 * <p> for nodes </p>
 * <p> * make the node serializable</p>
 * <p> * add new OpenAction("application/x-mime-for-node",this) to returned actions in {@link Node#getActions(boolean) }</p>
 * 
 * <p>For more information see {@see <a href="http://netbeans.dzone.com/nb-multiview-editor-for-nodes">How to Create MultiView Editors for Nodes}</a>
 * 
 * 
 * 
 * @author Merijn Zengers
 */
@Messages({"OpenAction context menu display name=Open"})
public class OpenAction<T extends Serializable & Lookup.Provider> extends AbstractAction {

    private String mimeType;
    private T context;

    public OpenAction(String mimeType, T context) {
        super(Bundle.OpenAction_context_menu_display_name());
        this.mimeType = mimeType;
        this.context = context;
    }

    @Override
    public void actionPerformed(ActionEvent ae) {
        TopComponent tc = MultiViews.createMultiView(mimeType, context);
        tc.open();
        tc.requestActive();
    }
}
