/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util.annotationhandlers;

import java.io.IOException;
import java.io.OutputStream;
import javax.lang.model.element.Element;
import javax.lang.model.type.TypeKind;
import javax.lang.model.type.TypeMirror;
import nl.cloudfarming.client.util.annotations.ASIdentifying;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Gerben Feenstra
 */
@ServiceProvider(service = AnnotationHandler.class)
public class ASEqualsHandler implements AnnotationHandler {

    @Override
    public boolean canHandle(Class annotationClass) {
        return ASIdentifying.class.isAssignableFrom(annotationClass);
    }

    @Override
    public void handle(OutputStream out, Element element) throws IOException{
        String name = AnnotationUtils.capitalize(element.getSimpleName().toString());
        
        TypeMirror type = element.asType();
        TypeKind kind = type.getKind();
        if(kind.isPrimitive()){                                                
            out.write(("\n").getBytes()); 
            out.write(("       if (this." + name + " != other." + name + ") {\n").getBytes());
            out.write(("          return false;\n").getBytes());
            out.write(("       }\n").getBytes());                                     
        }
        else{
            out.write(("\n").getBytes()); 
            out.write(("       if (this." + name + " != other." + name + " && (this." + name + " == null || !this." + name + ".equals(other." + name + "))) {\n").getBytes());
            out.write(("          return false;\n").getBytes());
            out.write(("       }\n").getBytes());                    
        }
    }
}
